@@ -28,8 +28,11 @@ function makeHeaderInfoTab() {
 
   // Look to see if the minimum requirement is there
   if (theDocument && 'defaultView' in theDocument && 'controllers' in theDocument.defaultView) {
-    loc = theDocument.location.protocol;
-    var controller = theDocument.defaultView.controllers.getControllerForCommand('livehttpheaders');
+    var loc = theDocument.location.protocol;
+    var controllers = theDocument.defaultView.controllers
+    while (controllers.wrappedJSObject)
+      controllers = controllers.wrappedJSObject
+    var controller = controllers.getControllerForCommand('livehttpheaders');
 
     // The controller might be wrapped multiple times
     while (controller && !('headers' in controller))
@@ -78,7 +81,7 @@ function makeHeaderInfoTab() {
       }
       responseheaders.rowCountChanged(0, length);
       responseheaders.enablehScroll("headerinfo-response-scroll","headerinfo-response-value");
-    } else if(loc=='http:' || loc=='https:') {
+    } else if (loc=='http:' || loc=='https:') {
       // If we are here, it must be because the nsHeaderInfo component wasn't registered
       document.getElementById("headerinfoCNR").hidden = false;
       document.getElementById("headerinfoDeck").selectedIndex = 1;
